ReorderElementsCommand class

Inheritance

Constructors

ReorderElementsCommand({required int oldIndex, required int newIndex})

Properties

hashCode int
The hash code for this object.
no setterinherited
newIndex int
final
oldIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(EditorState state) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
undo(EditorState state) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited