KoiTemplateLoader class

Constructors

KoiTemplateLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadAllTemplates() Future<List<KoiTemplateManifest>>
从 package assets 中异步加载所有的 JSON 模板