ElementInspectorBuilder<T extends KoiPrintElement> class abstract

Implementers

Constructors

ElementInspectorBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, String elementId, T element) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(BuildContext context, String elementId, T newElement) → void
封装便捷的更新钩子。从 EditorState 获取最新元素作为 oldElement, 避免闭包捕获的过期引用导致 Undo 链断裂。

Operators

operator ==(Object other) bool
The equality operator.
inherited