InspectorRegistry class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildInspector(
BuildContext context, String elementId, KoiPrintElement element) → Widget -
ensureInitialized(
void registerFn(InspectorRegistry r)) → void - 确保注册只执行一次,防止热重载时重复创建 Builder 实例。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T extends KoiPrintElement> (ElementInspectorBuilder< T> builder) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → InspectorRegistry
-
final